// Dosya: public/assets/js/components/common/Alert.jsx | Yol: /home/main/public_html/ai.zefre.net/stocksense/public/assets/js/components/common/Alert.jsx
/**
 * StockSense - Shopify Stok Optimizasyonu Uygulaması
 * 
 * Geliştiren: Muhsin İŞSEVER
 * E-posta: muhsin.issever@gmail.com
 * Web sitesi: https://ai.zefre.net/
 * R10 Profili: https://www.r10.net/profil/193-gneral.html
 * GitHub: www.github.com/gneral
 */

import React, { useState, useEffect } from 'react';

const Alert = ({ type = 'info', message, dismissible = true, timeout = 0 }) => {
  const [visible, setVisible] = useState(true);
  
  // Alert tiplerine göre stiller
  const alertStyles = {
    success: 'bg-green-100 border-green-500 text-green-700 dark:bg-green-900 dark:border-green-500 dark:text-green-200',
    error: 'bg-red-100 border-red-500 text-red-700 dark:bg-red-900 dark:border-red-500 dark:text-red-200',
    warning: 'bg-yellow-100 border-yellow-500 text-yellow-700 dark:bg-yellow-900 dark:border-yellow-500 dark:text-yellow-200',
    info: 'bg-blue-100 border-blue-500 text-blue-700 dark:bg-blue-900 dark:border-blue-500 dark:text-blue-200'
  };
  
  // İkon bileşenleri
  const alertIcons = {
    success: (
      <svg className="w-5 h-5" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg">
        <path fillRule="evenodd" d="M10 18a8 8 0 100-16 8 8 0 000 16zm3.707-9.293a1 1 0 00-1.414-1.414L9 10.586 7.707 9.293a1 1 0 00-1.414 1.414l2 2a1 1 0 001.414 0l4-4z" clipRule="evenodd"></path>
      </svg>
    ),
    error: (
      <svg className="w-5 h-5" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg">
        <path fillRule="evenodd" d="M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-7 4a1 1 0 11-2 0 1 1 0 012 0zm-1-9a1 1 0 00-1 1v4a1 1 0 102 0V6a1 1 0 00-1-1z" clipRule="evenodd"></path>
      </svg>
    ),
    warning: (
      <svg className="w-5 h-5" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg">
        <path fillRule="evenodd" d="M8.257 3.099c.765-1.36 2.722-1.36 3.486 0l5.58 9.92c.75 1.334-.213 2.98-1.742 2.98H4.42c-1.53 0-2.493-1.646-1.743-2.98l5.58-9.92zM11 13a1 1 0 11-2 0 1 1 0 012 0zm-1-8a1 1 0 00-1 1v3a1 1 0 002 0V6a1 1 0 00-1-1z" clipRule="evenodd"></path>
      </svg>
    ),
    info: (
      <svg className="w-5 h-5" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg">
        <path fillRule="evenodd" d="M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-7-4a1 1 0 11-2 0 1 1 0 012 0zm-1 9a1 1 0 102 0v-5a1 1 0 00-2 0v5z" clipRule="evenodd"></path>
      </svg>
    )
  };
  
  // Otomatik kapanma için timer
  useEffect(() => {
    let timer;
    
    if (timeout > 0) {
      timer = setTimeout(() => {
        setVisible(false);
      }, timeout);
    }
    
    return () => {
      if (timer) clearTimeout(timer);
    };
  }, [timeout]);
  
  // Alert görünmüyorsa render etme
  if (!visible) return null;
  
  // Alert içeriği
  return (
    <div className={`${alertStyles[type]} border-l-4 p-4 mb-4 rounded-md flex items-start`} role="alert">
      <div className="flex-shrink-0 mr-3 mt-0.5">
        {alertIcons[type]}
      </div>
      <div className="flex-grow">
        {typeof message === 'string' ? (
          <p className="text-sm">{message}</p>
        ) : (
          message
        )}
      </div>
      {dismissible && (
        <button 
          type="button" 
          className="ml-auto -mx-1.5 -my-1.5 bg-transparent text-current p-1.5 inline-flex items-center justify-center rounded-md focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-gray-50 focus:ring-indigo-500"
          onClick={() => setVisible(false)}
          aria-label="Close"
        >
          <span className="sr-only">Close</span>
          <svg className="w-4 h-4" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M6 18L18 6M6 6l12 12"></path>
          </svg>
        </button>
      )}
    </div>
  );
};

export default Alert;
